# fusion_tables_api.spec
require 'spec_helper'

describe FusionTablesAPI do
  before do 
    @client_cred = { client_id: "FaKE-1D", client_secret: "s3EkR1t" }
    @oauth_tokens = { access_token: "SuM-C0mb0-04-th15", refresh_token: "jUs7_a5-Wld" }
    @google_api_client_options = { 
      application_name: "Test", 
      application_version: "1.0alpha"
    }
  end
  
  describe "when initializing FusionTablesAPI" do 
    it "should raise an ArgumentError error if no parameters passed" do
      expect { FusionTablesAPI.new }.to raise_error(ArgumentError)
    end

    it "should not raise an error if the client credentials are passed" do
      expect { FusionTablesAPI.new(@client_cred, @google_api_client_options) }.to_not raise_error
    end 
  end

  before { @ft_no_tokens = FusionTablesAPI.new(@client_cred, nil, @google_api_client_options) }

  subject { @ft_no_tokens }
  it { should respond_to(:client) }

  describe "after being initialized without access_tokens" do
    let(:authorization) { @ft_no_tokens.client.authorization }
    it "should have its client id set" do
      authorization.client_id.should equal(@client_cred[:client_id])
    end

    it "should have its client secret set" do
      authorization.client_secret.should equal(@client_cred[:client_secret])
    end

    it "should not have an access token set" do
      authorization.access_token.should be_nil
    end
  end


  before { @ft_with_tokens = FusionTablesAPI.new(@client_cred,  @oauth_tokens, @google_api_client_options) }

  describe "after being initialized with tokens" do 
    let(:authorization) { @ft_with_tokens.client.authorization }
    it "should have its client id set" do
      authorization.client_id.should equal(@client_cred[:client_id])
    end

    it "should have its client secret set" do
      authorization.client_secret.should equal(@client_cred[:client_secret])
    end

    it "should not have an access token set" do
      authorization.access_token.should equal(@oauth_tokens[:access_token])
    end

    it "should not have an access token set" do
      authorization.refresh_token.should equal(@oauth_tokens[:refresh_token])
    end
  end

  describe "when initialized without GoogleAPI Client options" do
    it "should not raise an error" do
     expect { FusionTablesAPI.new(@client_cred) }.to_not raise_error
    end
    it "should not raise an error when access_token in argument as well" do
     expect { FusionTablesAPI.new(@client_cred, @oauth_tokens) }.to_not raise_error
    end
  end
end
